<?php
/**
* Plugin Name: WPM Options
* Plugin URI: https://wpmaster.ru/plugins/wpm-options/
* Description: WPM Options - plugin for customize Wordpress, add analytic codes. 
* Version: 0.1
* Author: Wordpress Master
* Author URI: https://wpmaster.ru
* License: GPLv2 or later
* License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

class WPMOptions {
    
    public function __construct() {
        $this->plugin               = new stdClass;
        $this->plugin->name         = 'wpm-options';
        $this->plugin->displayName  = 'WPM Site Options';
        $this->plugin->version      = '0.1';
        $this->plugin->folder       = plugin_dir_path( __FILE__ );
        $this->plugin->url          = plugin_dir_url( __FILE__ );
        $this->plugin->db_welcome_dismissed_key = $this->plugin->name . '_welcome_dismissed_key';

	// Hooks
	add_action( 'admin_init', array( &$this, 'registerSettings' ) );
        add_action( 'admin_menu', array( &$this, 'adminPanelsAndMetaBoxes' ) );
        add_action( 'admin_notices', array( &$this, 'dashboardNotices' ) );
        add_action( 'wp_ajax_' . $this->plugin->name . '_dismiss_dashboard_notices', array( &$this, 'dismissDashboardNotices' ) );

        add_action( 'wp_head', array( &$this, 'frontendHeader' ) );
	add_action( 'wp_footer', array( &$this, 'frontendFooter' ) );
        
        if(function_exists('wp_body_open')){
            add_action( 'wp_body_open', array( &$this, 'frontendBody' ));
        }
        
    } 

    function dashboardNotices() {
        global $pagenow;

        if ( !get_option( $this->plugin->db_welcome_dismissed_key ) ) {
        	if ( ! ( $pagenow == 'options-general.php' && isset( $_GET['page'] ) && $_GET['page'] == 'wpm-options' ) ) {
	            $setting_page = admin_url( 'options-general.php?page=' . $this->plugin->name );
	            // load the notices view
                include_once( $this->plugin->folder . '/views/dashboard-notices.php' );
        	}
        }
    }

    /**
     * Dismiss the welcome notice for the plugin
     */
    function dismissDashboardNotices() {
    	check_ajax_referer( $this->plugin->name . '-nonce', 'nonce' );
        // user has dismissed the welcome notice
        update_option( $this->plugin->db_welcome_dismissed_key, 1 );
        exit;
    }

	/**
	* Register Settings
	*/
	function registerSettings() {
		register_setting( $this->plugin->name, 'wpm_options_insert_header', 'trim' );
                register_setting( $this->plugin->name, 'wpm_options_insert_body', 'trim' );
		register_setting( $this->plugin->name, 'wpm_options_insert_footer', 'trim' );
	}

	/**
    * Register the plugin settings panel
    */
    function adminPanelsAndMetaBoxes() {
    	add_submenu_page( 'options-general.php', $this->plugin->displayName, $this->plugin->displayName, 'manage_options', $this->plugin->name, array( &$this, 'adminPanel' ) );
	}

    /**
    * Output the Administration Panel
    * Save POSTed data from the Administration Panel into a WordPress option
    */
    function adminPanel() {
		// only admin user can access this page
		if ( !current_user_can( 'administrator' ) ) {
			echo '<p>Sorry, you are not allowed to access this page.</p>';
			return;
		}

    	// Save Settings
        if ( isset( $_REQUEST['submit'] ) ) {
        	// Check nonce
			if ( !isset( $_REQUEST[$this->plugin->name.'_nonce'] ) ) {
	        	// Missing nonce
	        	$this->errorMessage = 'nonce field is missing. Settings NOT saved.';
        	} elseif ( !wp_verify_nonce( $_REQUEST[$this->plugin->name.'_nonce'], $this->plugin->name ) ) {
	        	// Invalid nonce
	        	$this->errorMessage = 'Invalid nonce specified. Settings NOT saved.';
        	} else {
	        	// Save
				// $_REQUEST has already been slashed by wp_magic_quotes in wp-settings
				// so do nothing before saving
	    		update_option( 'wpm_options_insert_header', $_REQUEST['wpm_options_insert_header'] );
                        update_option( 'wpm_options_insert_body', $_REQUEST['wpm_options_insert_body'] );
	    		update_option( 'wpm_options_insert_footer', $_REQUEST['wpm_options_insert_footer'] );
	    		update_option( $this->plugin->db_welcome_dismissed_key, 1 );
				$this->message = 'Settings Saved.';
			}
        }

        $this->settings = array(
            'wpm_options_insert_header' => esc_html( wp_unslash( get_option( 'wpm_options_insert_header' ) ) ),
            'wpm_options_insert_body' => esc_html( wp_unslash( get_option( 'wpm_options_insert_body' ) ) ),
            'wpm_options_insert_footer' => esc_html( wp_unslash( get_option( 'wpm_options_insert_footer' ) ) ),
        );


        include_once( $this->plugin->folder . '/views/settings.php' );
    }


    function frontendHeader() {
        $this->output( 'wpm_options_insert_header' );
    }
    
    function frontendBody() {
        $this->output( 'wpm_options_insert_body' );
    }

    function frontendFooter() {
        $this->output( 'wpm_options_insert_footer' );        
    }
    
    function output( $setting ) {

        if ( is_admin() || is_feed() || is_robots() || is_trackback() ) {
			return;
        }

		if ( apply_filters( 'disable_wp_options', false ) ) {
			return;
		}

		if ( 'wpm_options_insert_footer' == $setting && apply_filters( 'disable_wp_options_footer', false ) ) {
			return;
		}
                
		if ( 'wpm_options_insert_body' == $setting && apply_filters( 'disable_wp_options_body', false ) ) {
			return;
		}

		if ( 'wpm_options_insert_header' == $setting && apply_filters( 'disable_wp_options_header', false ) ) {
			return;
		}                
		$meta = get_option( $setting );
		if ( empty( $meta ) ) {
			return;
		}
		if ( trim( $meta ) == '' ) {
			return;
		}
		echo wp_unslash( $meta );
	}
    
    
}
$wpm_options = new WPMOptions();